#
# spec file for package raw-thumbnailer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           raw-thumbnailer
Version:        47.0.1
Release:        1.3
Summary:        RAW images thumbnailer for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://libopenraw.freedesktop.org
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Summary(ru):    Генератор миниатюр RAW изображений для GNOME
BuildRequires:  cargo
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(libopenraw-gnome-0.3)
Requires:       shared-mime-info >= 0.90

%description
A lightweight and fast thumbnailer used by Nautilus for digital camera RAW files.

%description -l ru
Быстрое и не требовательное приложение, используемое Nautilus для создание миниатюр RAW файлов, полученных с цифровых камер.

%prep
%autosetup -p1 -a1

%build
%meson -Dprofile=release
%meson_build

%install
%meson_install

%check
%meson_test

%files
%defattr(-,root,root)
%license COPYING
%doc NEWS ChangeLog
%{_bindir}/raw-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/raw.thumbnailer
%{_datadir}/mime/packages/raw-thumbnailer.xml

%changelog
* Wed Sep 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier upgrading.
* Mon Sep 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0.1:
  + Fix the module name / tarballs.
- Changes from version 47.0.0:
  + Rewrote in Rust.
  + Uses meson to build.
- Add meson BuildRequires and replace configure based macros with
  meson_* based macros.
- Add cargo BuildRequires: new dependency as raw-thumbnailer was
  rewritten in rust.
- Drop obsoleted patches:
  + raw-thumbnailer-3.0.0-add-Panasonic.patch
  + raw-thumbnailer-3.0.0-mime-data-remove.patch
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Sun Apr 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update build system to use libopenraw-gnome-0.3 instead of
  libopenraw-gnome-0.1.
- Specifically require pkgconfig(libopenraw-gnome-0.3) for
  building as we modify the build scripts to look for this and it
  makes it easier to track build issues when libopenraw is updated
  in the future.
* Wed Jun  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Replace pkgconfig(libopenraw-gnome-1.0) BuildRequires with
  libopenraw-devel: the .pc file changed name between 0.0.x and
  0.1.x. Requiring the generic -devel name is easier than following
  upstreams namechanges.
- In case we build against libopenraw-gnome-0.1, update the build
  system to look for the right pc file using sed.
* Fri Mar 29 2013 svalx@svalx.net
- Remove Obsolete tag for dcraw-gnome package - it is too old.
- Change summary and description of the package, add it's Russian
  translation.
- Add raw-thumbnailer-3.0.0-mime-data-remove.patch: Remove mime
  type definitions: it is duplicate of definition in
  shared-mime-info package.
- Add shared-mime-info Requires.
- Add raw-thumbnailer-3.0.0-add-Panasonic.patch: dd support for
  image/x-panasonic-raw and image/x-panasonic-raw2.
* Sat Dec 24 2011 vuntz@opensuse.org
- Change libopenraw-devel BuildRequires to
  pkgconfig(libopenraw-gnome-1.0).
- Add explicit pkgconfig(gdk-pixbuf-2.0) and pkgconfig(gio-2.0)
  BuildRequires, since they are checked for in configure.
* Tue Dec 20 2011 dimstar@opensuse.org
- Update to version 3.0.0:
  + Remove gnome-vfs dependency
  + Adapt everything for Gnome3
  + Require libopenraw 0.0.9
  + Tarballs in bz2 and xz
- Changes from version 0.99.2:
  + NEW: add Minolta raw mime type to the handlers.
  + NEW: bump requirement to libopenraw 0.0.5
- Drop raw-thumbnailer-make382.patch: fixed upstream
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as we no longer carry patches.
- Drop no longer needed BuildRequires: gnome-vfs2-devel,
  gtk2-devel, libgsf-devel, libjpeg-devel, libstdc++-devel,
  perl-XML-Parser.
- Drop gconf schema handling: the thumbnailer was ported to GNOME3
  infrastructure.
- Remove openSUSE < 10.3 /opt prefix handling.
- Clean spec file using spec-cleaner.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Remove shared-mime-info Requires: if it's not there, then we
  simply don't need to update the mime database.
* Sat Sep 11 2010 dimstar@opensuse.org
- Add raw-thumbnailer-make382.patch: Fix build with make 3.82.
  Patch sent to Hub by mail.
- Add gnome-common BuildRequires.
- Add gnome-autogen.sh call in build section.
- Clean spec file using spec-cleaner.
* Thu Apr 10 2008 sbrabec@suse.cz
- Added missing gconf scriptlet.
- Provide and obsolete dcraw-gnome.
- Fixed PreReq -> Requires.
* Thu Apr  3 2008 hfiguiere@suse.de
- Initial checkin
